package fr.graphit.bootstrap;

import java.util.Arrays;

import com.google.inject.Key;
import com.google.inject.name.Names;
import org.apache.log4j.Logger;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.servlet.GuiceServletContextListener;

import fr.graphit.core.CoreModule;
import fr.graphit.web.WebModule;
import fr.graphit.web.filter.FilterModule;

/** The startup listener is in charge of starting the application and loading required data.
 * @author Thomas Clarisse
 * @see CoreModule
 * @see WebModule
 */
public class StartupListener extends GuiceServletContextListener {

	private static final Logger logger = Logger.getLogger(StartupListener.class);
	
	@Override
	protected Injector getInjector() {
		
		logger.info("Starting Graphit...");
		
		logger.info("Starting Modules...");
		Injector injector = Guice.createInjector(new CoreModule(), new FilterModule(), new WebModule());
		logger.info("Modules are started.");
		
		logger.info("Performing consistency checks...");
		BootstrapService bootstrap = injector.getInstance(BootstrapService.class);
		bootstrap.propertiesCheck(Arrays.asList("host", "user", "password", "port", "schema","create.schema.on.startup"));

        if(injector.getInstance(Key.get(String.class, Names.named("create.schema.on.startup"))).equals("1")) {
            bootstrap.schemaConsistencyCheck();
        }

        bootstrap.modelCheck();

		logger.info("Consistency checks are over.");
		
		logger.info("Graphit is started.");
		
		return injector;
	}

}
