CREATE TABLE IF NOT EXISTS edges (
  id_parent int(11) NOT NULL,
  id_child int(11) NOT NULL,
  PRIMARY KEY (id_parent,id_child),
  KEY fk_mother_product (id_parent),
  KEY fk_daughter_product (id_child),
  CONSTRAINT fk_daughter_product FOREIGN KEY (id_child) REFERENCES nodes (id) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT fk_mother_product FOREIGN KEY (id_parent) REFERENCES nodes (id) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS nodes (
  id int(11) NOT NULL AUTO_INCREMENT,
  name varchar(100) NOT NULL,
  id_type int(11) NOT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY name_UNIQUE (name),
  KEY fk_node_type (id_type),
  CONSTRAINT fk_node_type FOREIGN KEY (id_type) REFERENCES type_definition (id) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB AUTO_INCREMENT=217 DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS property_definition (
  id int(11) NOT NULL AUTO_INCREMENT,
  name varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  component varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  value_list varchar(500) CHARACTER SET latin1 DEFAULT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS property_values (
  id_node int(11) NOT NULL,
  id_property int(11) NOT NULL,
  string_value varchar(100) DEFAULT NULL,
  date_value datetime DEFAULT NULL,
  text_value text,
  boolean_value tinyint(1) DEFAULT NULL,
  integer_value int(11) DEFAULT NULL,
  PRIMARY KEY (id_node,id_property),
  KEY fk_property_node (id_node),
  KEY fk_property_property (id_property),
  CONSTRAINT fk_property_node FOREIGN KEY (id_node) REFERENCES nodes (id) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT fk_property_property FOREIGN KEY (id_property) REFERENCES property_definition (id) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS settings (
  code varchar(45) CHARACTER SET latin1 NOT NULL,
  value varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  PRIMARY KEY (code)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS type_composition (
  id_type int(11) NOT NULL,
  id_property int(11) NOT NULL,
  PRIMARY KEY (id_type,id_property),
  KEY fk_type_property_composition (id_property),
  KEY fk_property_type_composition (id_type),
  CONSTRAINT fk_property_type_composition FOREIGN KEY (id_type) REFERENCES type_definition (id) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT fk_type_property_composition FOREIGN KEY (id_property) REFERENCES property_definition (id) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS type_definition (
  id int(11) NOT NULL AUTO_INCREMENT,
  name varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  color varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  shape varchar(45) CHARACTER SET latin1 DEFAULT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY name_UNIQUE (name)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS views (
  id int(11) NOT NULL AUTO_INCREMENT,
  name varchar(100) CHARACTER SET latin1 DEFAULT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY name_UNIQUE (name)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS views_composition (
  id_view int(11) NOT NULL,
  id_node int(11) NOT NULL,
  PRIMARY KEY (id_view,id_node),
  KEY fk_subgraph_item (id_node),
  KEY fk_view_node (id_node),
  KEY fk_view_view (id_view),
  CONSTRAINT fk_view_node FOREIGN KEY (id_node) REFERENCES nodes (id) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT fk_view_view FOREIGN KEY (id_view) REFERENCES views (id) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;