package fr.graphit.core;

import java.io.IOException;
import java.sql.Connection;
import java.util.Properties;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Logger;

import com.google.inject.AbstractModule;
import com.google.inject.Singleton;
import com.google.inject.name.Names;

import fr.graphit.bootstrap.BootstrapService;
import fr.graphit.bootstrap.BootstrapServiceImpl;
import fr.graphit.core.api.ModelDAO;
import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesDAO;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.dao.ModelDAOImpl;
import fr.graphit.core.dao.NodesDAOImpl;
import fr.graphit.core.database.ConnectionProvider;
import fr.graphit.core.database.DatabaseHelper;
import fr.graphit.core.service.ModelServiceImpl;
import fr.graphit.core.service.NodesServiceImpl;

/**
 * CoreModule is initiating the main services of the application.
 * @author Thomas Clarisse
 */
public class CoreModule extends AbstractModule {
	
	private static final Logger logger = Logger.getLogger(CoreModule.class);
	
	@Override
	protected void configure() {
		
		logger.info("Starting Graphit Core Module...");
		
		bind(NodesDAO.class)
			.to(NodesDAOImpl.class)
			.in(Singleton.class);
		
		bind(NodesService.class)
			.to(NodesServiceImpl.class)
			.in(Singleton.class);
		
		bind(ModelDAO.class)
			.to(ModelDAOImpl.class)
			.in(Singleton.class);

		bind(ModelService.class)
			.to(ModelServiceImpl.class)
			.in(Singleton.class);
		
		bind(Connection.class)
			.toProvider(ConnectionProvider.class);
		
		bind(BootstrapService.class)
			.to(BootstrapServiceImpl.class);
		
		bind(DatabaseHelper.class)
			.in(Singleton.class);
		
		
		Properties properties = new Properties();
		String currentPath = null;
		try {
			currentPath = "/fr/graphit/conf/database.properties";
			properties.load(this.getClass().getClassLoader().getResourceAsStream(currentPath));
			currentPath = "fr/graphit/conf/custom-database.properties";
			properties.load(this.getClass().getClassLoader().getResourceAsStream(currentPath));
		}
		catch (IOException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			logger.info("Unable to load configuration file " + currentPath + " : " + e.getMessage());
		}
		catch (NullPointerException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			logger.info("Unable to load configuration file " + currentPath + " : " + e.getMessage());
		}
		finally {
			Names.bindProperties(binder(), properties);
		}
		
		logger.info("Graphit Core Module is started.");
		
	}
	
}
