package fr.graphit.core.api;

import java.util.List;
import java.util.Map;

import fr.graphit.core.api.exception.database.DatabaseException;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public interface ModelDAO {

	public List<Type> getTypes() throws DatabaseException;
	public Type getType(Integer id) throws DatabaseException, TypeNotFoundException;
	public List<Property> getTypeProperties(Type type) throws DatabaseException, TypeNotFoundException; 
	
	public List<View> getViews() throws DatabaseException;
	public View getView(Integer id) throws DatabaseException, ViewNotFoundException;
	public void deleteView(View view) throws DatabaseException, ViewNotFoundException;
	public View createView(String name) throws DatabaseException, NameAlreadyInUseException;
	public View updateView(View view) throws DatabaseException, ViewNotFoundException;
	
	public View addNodeToView(Node node, View target) throws DatabaseException, ViewNotFoundException, NodeNotFoundException;
	public View deleteNodeFromView(Node node, View target) throws DatabaseException, ViewNotFoundException, NodeNotFoundException;
	
	public Map<String, String> getSettings() throws DatabaseException;
	
}
