package fr.graphit.core.api;

import java.util.List;
import java.util.Map;

import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.UnableToCreateViewException;
import fr.graphit.core.api.exception.model.UnableToDeleteViewException;
import fr.graphit.core.api.exception.model.UnableToModifyViewException;
import fr.graphit.core.api.exception.model.UnableToRetrieveSettingsException;
import fr.graphit.core.api.exception.model.UnableToRetrieveTypesException;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.UnableToUpdateViewException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public interface ModelService {

	public List<Type> getTypes() throws UnableToRetrieveTypesException;
	public Type getType(Integer id) throws UnableToRetrieveTypesException, TypeNotFoundException;
	public List<Property> getTypeProperties(Type type) throws UnableToRetrieveTypesException, TypeNotFoundException; 
	
	public List<View> getViews() throws UnableToRetrieveViewsException;
	public View getView(Integer id) throws UnableToRetrieveViewsException, ViewNotFoundException;
	public void deleteView(View view) throws UnableToRetrieveViewsException, ViewNotFoundException, UnableToDeleteViewException;
	public View createView(String name) throws UnableToCreateViewException, NameAlreadyInUseException;
	public View updateView(View view) throws UnableToUpdateViewException, ViewNotFoundException;
	
	public View addNodeToView(Node node, View target) throws UnableToModifyViewException, ViewNotFoundException, NodeNotFoundException;
	public View deleteNodeFromView(Node node, View target) throws UnableToModifyViewException, ViewNotFoundException, NodeNotFoundException;
	
	public Map<String, String> getSettings() throws UnableToRetrieveSettingsException;
	
}
