package fr.graphit.core.api;

import java.util.List;
import java.util.Map;

import fr.graphit.core.api.exception.database.DatabaseException;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.EdgeAlreadyExistsException;
import fr.graphit.core.api.exception.node.EdgeNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public interface NodesDAO {

	public List<Node> getAllNodes(Boolean order) throws DatabaseException;
	public Node getNodeById(Integer id) throws NodeNotFoundException, DatabaseException;
	public List<Node> searchNodesByName(String name, Boolean strict) throws DatabaseException;
	public List<Node> searchNodesByView(View view) throws ViewNotFoundException, DatabaseException;
	
	public List<Node> getNodeParents(Node target, Integer level) throws NodeNotFoundException, DatabaseException;
	public List<Node> getNodeChildren(Node target, Integer level) throws NodeNotFoundException, DatabaseException;
	public Map<Property, Object> getNodeProperties(Node target) throws NodeNotFoundException, DatabaseException;
	
	public Node updateNode(Node updatedNode) throws NodeNotFoundException, DatabaseException;
	public Node createNode(String name, Type type) throws NameAlreadyInUseException, TypeNotFoundException, DatabaseException;
	public void deleteNode(Node deletedNode) throws NodeNotFoundException, DatabaseException;
	
	public void createEdge(Node parent, Node child) throws NodeNotFoundException, EdgeAlreadyExistsException, DatabaseException;
	public void breakEdge(Node parent, Node child) throws NodeNotFoundException, EdgeNotFoundException, DatabaseException;				
	
}