package fr.graphit.core.api;

import java.util.List;
import java.util.Map;

import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.EdgeAlreadyExistsException;
import fr.graphit.core.api.exception.node.EdgeNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToBreakEdgeException;
import fr.graphit.core.api.exception.node.UnableToCreateEdgeException;
import fr.graphit.core.api.exception.node.UnableToCreateNodeException;
import fr.graphit.core.api.exception.node.UnableToDeleteNodeException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.exception.node.UnableToUpdateNodeException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public interface NodesService {

	public List<Node> getAllNodes(Boolean order) throws UnableToRetrieveNodesException;
	public Node getNodeById(Integer id) throws NodeNotFoundException, UnableToRetrieveNodesException;
	public List<Node> searchNodesByName(String name, Boolean strict) throws UnableToRetrieveNodesException;
	public List<Node> searchNodesByView(View view) throws UnableToRetrieveNodesException, ViewNotFoundException;
	
	public List<Node> getNodeParents(Node target, Integer level) throws NodeNotFoundException, UnableToRetrieveNodesException;
	public List<Node> getNodeChildren(Node target, Integer level) throws NodeNotFoundException, UnableToRetrieveNodesException;
	public Map<Property, Object> getNodeProperties(Node target) throws NodeNotFoundException, UnableToRetrieveNodesException;
	
	public Node updateNode(Node updatedNode) throws NodeNotFoundException, UnableToUpdateNodeException;
	public Node createNode(String name, Type type) throws NameAlreadyInUseException, UnableToCreateNodeException, TypeNotFoundException;
	public void deleteNode(Node deletedNode) throws NodeNotFoundException, UnableToDeleteNodeException;
	
	public void createEdge(Node parent, Node child) throws NodeNotFoundException, EdgeAlreadyExistsException, UnableToCreateEdgeException;
	public void breakEdge(Node parent, Node child) throws NodeNotFoundException, EdgeNotFoundException, UnableToBreakEdgeException;						
	
}
