package fr.graphit.core.api.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.google.inject.Inject;

import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;

public class Node {

	private NodesService nodesService;
	
	private Integer id;
	private String name;
	private Type type;
	
	private List<Node> parents;
	private List<Node> children;
	private Map<Property, Object> properties;
	
	@Inject
	public Node(NodesService nodesService) {
		this.nodesService = nodesService;
	}
	
	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}
	
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Type getType() {
		return type;
	}

	public void setType(Type type) {
		this.type = type;
	}
	
	
	
	public void setProperties(Map<Property, Object> properties) {
		this.properties = properties;
	}

	public Object property(Integer id) {
		if(properties == null) {
			this.properties();
		}
		
		for(Property property : properties.keySet()) {
			if(property.getId().equals(id)) {
				return properties.get(property);
			}
		}
		
		return null;
	}
	
	public Map<Property, Object> properties() {
		
		if(properties == null) {
			try {
				properties = nodesService.getNodeProperties(this);
			}
			catch (NodeNotFoundException e) {
				return new HashMap<Property, Object>();
			}
			catch (UnableToRetrieveNodesException e) {
				return new HashMap<Property, Object>();
			}
		}
		
		return properties;
	}

	public List<Node> parents() {
		
		if(parents == null) {
			try {
				parents = nodesService.getNodeParents(this, 1);
			}
			catch (NodeNotFoundException e) {
				return new ArrayList<Node>();
			}
			catch (UnableToRetrieveNodesException e) {
				return new ArrayList<Node>();
			}
		}
		
		return parents;
	}

	public List<Node> children() {
		if(children == null) {
			try {
				children = nodesService.getNodeChildren(this, 1);
			}
			catch (NodeNotFoundException e) {
				return new ArrayList<Node>();
			}
			catch (UnableToRetrieveNodesException e) {
				return new ArrayList<Node>();
			}
		}
		
		return children;
	}
	
	@Override
	public boolean equals(Object obj) {
		if (obj instanceof Node) {
			Node itemObj = (Node) obj;
			return itemObj.getId().equals(this.id);
		}
		return false;
	}

}