package fr.graphit.core.api.model;

import java.util.List;

import fr.graphit.core.api.ModelService;

/**
 * A property definition codify a property that can be use in the current graph application
 * 
 * @see ModelService
 * @author Thomas Clarisse
 *
 */
public class Property {

	private Integer id;
	private String name;
	private Boolean list;
	private List<String> listValues;
	private String sqlType;
	
	/**
	 * Build a new PropertyDefinition
	 * @param name name of the property
	 * @param id id of the property
	 * @param list is the property a list or not
	 * @param listValues possible values of the property if it's a list
	 * @param sqlType field to map in the database
	 */
	public Property(Integer id, String name, Boolean list, List<String> listValues, String sqlType) {
		this.name = name;
		this.id = id;
		this.list = list;
		this.listValues = listValues;
		this.sqlType = sqlType;
	}

	/**
	 * Get the id of the property
	 * @return property id
	 */
	public Integer getId() {
		return id;
	}
	
	/**
	 * Get the name of the property
	 * @return name of the property
	 */
	public String getName() {
		return name;
	}

	/**
	 * Is the property a list ?
	 * @return true if it's a list, false if not
	 */
	public Boolean getList() {
		return list;
	}

	/**
	 * Get the list of possible values of this list
	 * @return possible values for this property, null if it's not a list
	 */
	public List<String> getListValues() {
		return listValues;
	}

	/**
	 * Get the field to bind in database
	 * @return Field to bind in database
	 */
	public String getSqlType() {
		return sqlType;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof Property) {
			Property itemObj = (Property) obj;
			return itemObj.getId().equals(this.id);
		}
		return false;
	}
	
	

}
