package fr.graphit.core.api.model;

import java.util.ArrayList;
import java.util.List;

import com.google.inject.Inject;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.UnableToRetrieveTypesException;

/**
 * A type definition codify a node type that can be use in the current graph application
 * 
 * @see ModelService
 * @author Thomas Clarisse
 *
 */
public class Type {

	private ModelService modelService;
	
	private Integer id;
	private String name;
	private String color;
	private String shape;
	private List<Property> properties;
	
	@Inject
	public Type(ModelService modelService) {
		this.modelService = modelService;
	}

	public Integer getId() {
		return id;
	}
	
	public void setId(Integer id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getColor() {
		return color;
	}

	public void setColor(String color) {
		this.color = color;
	}

	public String getShape() {
		return shape;
	}


	public void setShape(String shape) {
		this.shape = shape;
	}

	public List<Property> properties() {
		if(properties == null) {
			try {
				properties = modelService.getTypeProperties(this);
			}
			catch (UnableToRetrieveTypesException e) {
				return new ArrayList<Property>();
			}
			catch (TypeNotFoundException e) {
				return new ArrayList<Property>();
			}
		}
		
		return properties;
	}
	
	public Property getProperty(Integer id) throws UnableToRetrieveTypesException, TypeNotFoundException {
		if(properties == null) {
			this.properties();
		}
		
		for(Property property : properties) {
			if(property.getId().equals(id)) {
				return property;
			}
		}
		
		return null;
	}
	
	@Override
	public boolean equals(Object obj) {
		if (obj instanceof Type) {
			Type itemObj = (Type) obj;
			return itemObj.getId().equals(this.id);
		}
		return false;
	}

	
	
}
