package fr.graphit.core.dao;

import java.sql.Connection;

import com.google.inject.Injector;
import com.google.inject.Provider;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.database.DatabaseHelper;

public abstract class AbstractDAO {
	
	protected Injector injector;
	
	protected static final String NODES = "nodes";
	protected static final String EDGES = "edges";
	protected static final String PROPERTY_DEFINITION = "property_definition";
	protected static final String PROPERTY_VALUES = "property_values";
	protected static final String SETTINGS = "settings";
	protected static final String TYPE_COMPOSITION = "type_composition";
	protected static final String TYPE_DEFINITION = "type_definition";
	protected static final String VIEWS = "views";
	protected static final String VIEWS_COMPOSITION = "views_composition";
	
	public AbstractDAO(Injector injector) {
		this.injector = injector;
	}
	
	protected Connection getConnection() {
		Provider<Connection> connectionProvider = injector.getProvider(Connection.class);
		return connectionProvider.get();
	}
	
	protected DatabaseHelper getDatabaseHelper() {
		return injector.getInstance(DatabaseHelper.class);
	}
	
	protected ModelService getModelService() {
		return injector.getInstance(ModelService.class);
	}
	
	protected NodesService getNodesService() {
		return injector.getInstance(NodesService.class);
	}
	
}
