package fr.graphit.core.database;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Logger;

import com.google.inject.Inject;
import com.google.inject.Provider;
import com.google.inject.name.Named;

public class ConnectionProvider implements Provider<Connection> {

	private static final Logger logger = Logger.getLogger(ConnectionProvider.class);
	
	private String databaseUrl;
	
	@Inject
	public ConnectionProvider(@Named("host") String host, @Named("user") String user, @Named("password") String password, @Named("port") String port, @Named("schema") String schema) {
		this.databaseUrl = "jdbc:mysql://"+host+":"+port+"/"+schema+"?user="+user+"&password="+password+"&useEncoding=true&characterEncoding=UTF-8";
	}
	
	@Override
	public Connection get() {
		// After bootstrap, there is always an error so 3 attemps are necessary to be sure to have a connection
			Integer attemps, currentAttemp;
			Connection newConnection = null;
			
			for(attemps = 3, currentAttemp = 1; currentAttemp<=attemps; currentAttemp++) {
				
				try {
					// trying to open a connection
					newConnection = DriverManager.getConnection(databaseUrl);
					newConnection.setAutoCommit(false);
					// if connection is not null, break the loop and return
					break;
				}
				catch (SQLException e) {
					if(logger.isDebugEnabled()) {
						logger.debug(ExceptionUtils.getStackTrace(e));
					}
					logger.info("Unable to open connection (attemp "+currentAttemp+" on "+attemps+")" + e.getMessage());
				}
			}
			
			return newConnection;
	}

}
