package fr.graphit.core.service;

import java.util.List;
import java.util.Map;

import com.google.inject.Inject;

import fr.graphit.core.api.ModelDAO;
import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.exception.database.DatabaseException;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.UnableToCreateViewException;
import fr.graphit.core.api.exception.model.UnableToDeleteViewException;
import fr.graphit.core.api.exception.model.UnableToModifyViewException;
import fr.graphit.core.api.exception.model.UnableToRetrieveSettingsException;
import fr.graphit.core.api.exception.model.UnableToRetrieveTypesException;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.UnableToUpdateViewException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public class ModelServiceImpl implements ModelService {

	private ModelDAO modelDao;

	@Inject
	public ModelServiceImpl(ModelDAO modelDao) throws DatabaseException {
		this.modelDao = modelDao;
	}

	@Override
	public List<Type> getTypes() throws UnableToRetrieveTypesException {
		try {
			return modelDao.getTypes();
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveTypesException();
		}
	}

	@Override
	public Type getType(Integer id) throws UnableToRetrieveTypesException, TypeNotFoundException {
		try {
			return modelDao.getType(id);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveTypesException();
		}
	}

	@Override
	public List<Property> getTypeProperties(Type type) throws UnableToRetrieveTypesException, TypeNotFoundException {
		try {
			return modelDao.getTypeProperties(type);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveTypesException();
		}
	}

	@Override
	public List<View> getViews() throws UnableToRetrieveViewsException {
		try {
			return modelDao.getViews();
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveViewsException();
		}
	}

	@Override
	public View getView(Integer id) throws UnableToRetrieveViewsException, ViewNotFoundException {
		try {
			return modelDao.getView(id);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveViewsException();
		}
	}

	@Override
	public View addNodeToView(Node node, View target) throws UnableToModifyViewException, ViewNotFoundException, NodeNotFoundException {
		try {
			return modelDao.addNodeToView(node, target);
		}
		catch (DatabaseException e) {
			throw new UnableToModifyViewException();
		}
	}

	@Override
	public View deleteNodeFromView(Node node, View target) throws UnableToModifyViewException, ViewNotFoundException, NodeNotFoundException {
		try {
			return modelDao.deleteNodeFromView(node, target);
		}
		catch (DatabaseException e) {
			throw new UnableToModifyViewException();
		}
	}

	@Override
	public Map<String, String> getSettings() throws UnableToRetrieveSettingsException {
		try {
			return modelDao.getSettings();
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveSettingsException();
		}
	}

	@Override
	public void deleteView(View view) throws UnableToRetrieveViewsException, ViewNotFoundException, UnableToDeleteViewException {
		try {
			modelDao.deleteView(view);
		}
		catch (DatabaseException e) {
			throw new UnableToDeleteViewException();
		}
	}

	@Override
	public View createView(String name) throws UnableToCreateViewException, NameAlreadyInUseException {
		try {
			return modelDao.createView(name);
		}
		catch (DatabaseException e) {
			throw new UnableToCreateViewException();
		}
	}

	@Override
	public View updateView(View view) throws UnableToUpdateViewException, ViewNotFoundException {
		try {
			return modelDao.updateView(view);
		}
		catch (DatabaseException e) {
			throw new UnableToUpdateViewException();
		}
	}
	
	
}
