package fr.graphit.core.service;

import java.util.List;
import java.util.Map;

import com.google.inject.Inject;

import fr.graphit.core.api.NodesDAO;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.database.DatabaseException;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.EdgeAlreadyExistsException;
import fr.graphit.core.api.exception.node.EdgeNotFoundException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToBreakEdgeException;
import fr.graphit.core.api.exception.node.UnableToCreateEdgeException;
import fr.graphit.core.api.exception.node.UnableToCreateNodeException;
import fr.graphit.core.api.exception.node.UnableToDeleteNodeException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.exception.node.UnableToUpdateNodeException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.core.api.model.View;

public class NodesServiceImpl implements NodesService {

	private NodesDAO nodesDao;

	@Inject
	public NodesServiceImpl(NodesDAO nodesDao) {
		this.nodesDao = nodesDao;
	}

	@Override
	public List<Node> getAllNodes(Boolean order) throws UnableToRetrieveNodesException {
		try {
			return nodesDao.getAllNodes(order);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public Node getNodeById(Integer id) throws NodeNotFoundException, UnableToRetrieveNodesException {
		try {
			return nodesDao.getNodeById(id);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public List<Node> searchNodesByName(String name, Boolean strict) throws UnableToRetrieveNodesException {
		try {
			return nodesDao.searchNodesByName(name, strict);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public List<Node> searchNodesByView(View view) throws UnableToRetrieveNodesException, ViewNotFoundException {
		try {
			return nodesDao.searchNodesByView(view);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public List<Node> getNodeParents(Node target, Integer level) throws NodeNotFoundException, UnableToRetrieveNodesException {
		try {
			return nodesDao.getNodeParents(target, level);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public List<Node> getNodeChildren(Node target, Integer level) throws NodeNotFoundException, UnableToRetrieveNodesException {
		try {
			return nodesDao.getNodeChildren(target, level);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public Map<Property, Object> getNodeProperties(Node target) throws NodeNotFoundException, UnableToRetrieveNodesException {
		try {
			return nodesDao.getNodeProperties(target);
		}
		catch (DatabaseException e) {
			throw new UnableToRetrieveNodesException();
		}
	}

	@Override
	public Node updateNode(Node updatedNode) throws NodeNotFoundException, UnableToUpdateNodeException {
		try {
			return nodesDao.updateNode(updatedNode);
		}
		catch (DatabaseException e) {
			throw new UnableToUpdateNodeException();
		}
	}

	@Override
	public Node createNode(String name, Type type) throws NameAlreadyInUseException, UnableToCreateNodeException, TypeNotFoundException {
		try {
			return nodesDao.createNode(name, type);
		}
		catch (DatabaseException e) {
			throw new UnableToCreateNodeException();
		}
	}

	@Override
	public void deleteNode(Node deletedNode) throws NodeNotFoundException, UnableToDeleteNodeException {
		try {
			nodesDao.deleteNode(deletedNode);
		}
		catch (DatabaseException e) {
			throw new UnableToDeleteNodeException();
		}

	}

	@Override
	public void createEdge(Node parent, Node child) throws NodeNotFoundException, EdgeAlreadyExistsException, UnableToCreateEdgeException {
		try {
			nodesDao.createEdge(parent, child);
		}
		catch (DatabaseException e) {
			throw new UnableToCreateEdgeException();
		}

	}

	@Override
	public void breakEdge(Node parent, Node child) throws NodeNotFoundException, EdgeNotFoundException, UnableToBreakEdgeException {
		try {
			nodesDao.breakEdge(parent, child);
		}
		catch (DatabaseException e) {
			throw new UnableToBreakEdgeException();
		}

	}

}
