package fr.graphit.web.api;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.EdgeAlreadyExistsException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToCreateEdgeException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;

public class AddLinkAPIService implements APIService {

	private Integer id_parent;
	private Integer id_child;
	private String format;
	
	private NodesService itemsService;
	
	@Inject
	public AddLinkAPIService(NodesService itemsService) {
		this.itemsService = itemsService;
		this.id_child = -1;
		this.id_parent = -1;
		this.format = "http";
	}
	
	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}
	
	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}
	
	private Reply<?> process() {
		String error = "";
		try {
			Node child = itemsService.getNodeById(id_child);
			Node parent = itemsService.getNodeById(id_parent);
			
			itemsService.createEdge(parent, child);
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<String>("ok")).as(Json.class);
			}
			return Reply.saying().ok();
		}
		catch (EdgeAlreadyExistsException e) {
			error = e.getMessage();
		}
		catch (NodeNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}
		catch (UnableToCreateEdgeException e) {
			error = e.getMessage();
		}
		
		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
		
	}

	public Integer getId_parent() {
		return id_parent;
	}

	public void setId_parent(Integer id_parent) {
		this.id_parent = id_parent;
	}

	public Integer getId_child() {
		return id_child;
	}

	public void setId_child(Integer id_child) {
		this.id_child = id_child;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}
	
}
