package fr.graphit.web.api;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.UnableToModifyViewException;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.View;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;

public class AddNodeToViewAPIService implements APIService {

	private Integer id_view;
	private Integer id_node;
	private String format;
	
	private NodesService nodesService;
	private ModelService modelService;
	
	@Inject
	public AddNodeToViewAPIService(ModelService modelService, NodesService nodesService) {
		this.modelService = modelService;
		this.nodesService = nodesService;
		this.id_view = -1;
		this.id_node = -1;
		this.format = "http";
	}
	
	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}
	
	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}
	
	private Reply<?> process() {
		String error = "";
		try {
			
			Node node = nodesService.getNodeById(id_node);
			View view = modelService.getView(id_view);
			
			modelService.addNodeToView(node, view);
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<String>("ok")).as(Json.class);
			}
			return Reply.saying().ok();
		}
		catch (UnableToModifyViewException e) {
			error = e.getMessage();
		}
		catch (ViewNotFoundException e) {
			error = e.getMessage();
		}
		catch (NodeNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveViewsException e) {
			error = e.getMessage();
		}
		
		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
		
	}

	public Integer getId_view() {
		return id_view;
	}

	public void setId_view(Integer id_view) {
		this.id_view = id_view;
	}

	public Integer getId_node() {
		return id_node;
	}

	public void setId_node(Integer id_node) {
		this.id_node = id_node;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}
	
}
