package fr.graphit.web.api;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToDeleteNodeException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;
import fr.graphit.web.exception.InvalidParametersException;

public class DeleteNodeAPIService implements APIService {

	private Integer node_id;
	private String format;
	
	private NodesService nodesService;

	@Inject
	public DeleteNodeAPIService(NodesService itemsService) {
		this.nodesService = itemsService;
		this.format = "http";
	}

	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}

	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}

	/**
	 * post methods return search candidates. The pattern to search is provided
	 * as post data
	 * 
	 * @return A list of candidates
	 */
	private Reply<?> process() {
		
		String error = "";
		try {
			if (node_id == null) {
				throw new InvalidParametersException();
			}
			
			Node toDelete = nodesService.getNodeById(node_id);

			nodesService.deleteNode(toDelete);
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<String>("ok")).as(Json.class);
			}
			return Reply.saying().ok();

		} 
		catch (UnableToDeleteNodeException e) {
			error = e.getMessage();
		}
		catch (InvalidParametersException e) {
			error = e.getMessage();
		}
		catch (NodeNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}

		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
	}

	public Integer getNode_id() {
		return node_id;
	}

	public void setNode_id(Integer node_id) {
		this.node_id = node_id;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}

	
	
}
