package fr.graphit.web.api;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.exception.model.UnableToDeleteViewException;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.model.View;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;
import fr.graphit.web.exception.InvalidParametersException;

public class DeleteViewAPIService implements APIService {

	private Integer view_id;
	private String format;
	
	private ModelService modelService;

	@Inject
	public DeleteViewAPIService(ModelService modelService) {
		this.modelService = modelService;
		this.format = "http";
	}

	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}

	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}

	private Reply<?> process() {
		
		String error = "";
		try {
			if (view_id == null) {
				throw new InvalidParametersException();
			}
			
			View toDelete = modelService.getView(view_id);

			modelService.deleteView(toDelete);
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<String>("ok")).as(Json.class);
			}
			return Reply.saying().ok();

		} 
		catch (InvalidParametersException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveViewsException e) {
			error = e.getMessage();
		}
		catch (ViewNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToDeleteViewException e) {
			error = e.getMessage();
		}

		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
	}

	

	public Integer getView_id() {
		return view_id;
	}

	public void setView_id(Integer view_id) {
		this.view_id = view_id;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}

	
	
}
