package fr.graphit.web.api;

import java.util.ArrayList;
import java.util.List;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;

public class GetLinksAPIService implements APIService {

	
	private Integer id_item; 
	private String format;

	private NodesService itemsService;
	
	@Inject
	public GetLinksAPIService(NodesService itemsService) {
		this.itemsService = itemsService;
		this.id_item = -1;
		this.format = "http";
	}
	
	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}
	
	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}
	
	private Reply<?> process() {
		String error = "";
		try {
			
			Node node = itemsService.getNodeById(id_item);

			GetLinksReply reply = new GetLinksReply();
			reply.setChildren(itemsService.getNodeChildren(node, 1));
			reply.setParents(itemsService.getNodeParents(node, 1));
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<GetLinksReply>(reply)).as(Json.class);
			}
			return Reply.saying().ok();
		}
		catch (NodeNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}
		
		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
	}

	

	public Integer getId_item() {
		return id_item;
	}

	public void setId_item(Integer id_item) {
		this.id_item = id_item;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}
	
	public class GetLinksReply {
		
		private List<Node> parents;
		private List<Node> children;
		
		public GetLinksReply() {
			this.parents = new ArrayList<Node>();
			this.children = new ArrayList<Node>();
		}

		public List<Node> getParents() {
			return parents;
		}

		public void setParents(List<Node> parents) {
			this.parents = parents;
		}

		public List<Node> getChildren() {
			return children;
		}

		public void setChildren(List<Node> children) {
			this.children = children;
		}
		
	}
	
}
