package fr.graphit.web.api;

import java.util.HashMap;
import java.util.Map;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;
import fr.graphit.web.exception.InvalidParametersException;

public class NodeAPIService implements APIService {

	private Integer node_id;
	private String format;
	
	private NodesService nodesService;

	@Inject
	public NodeAPIService(NodesService itemsService, ModelService model) {
		this.nodesService = itemsService;
		this.format = "http";
	}

	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}

	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}

	private Reply<?> process() {
		String error = "";
		try {
			if (node_id == null) {
				throw new InvalidParametersException();
			}

			if (format.equals("json")) {
				return Reply.with(
						new SuccessReply<LiteNode>(new LiteNode(nodesService.getNodeById(node_id)))).as(Json.class);
			}
			return Reply.saying().ok();

		} 
		catch (InvalidParametersException e) {
			error = e.getMessage();
		}
		catch (NodeNotFoundException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}

		if (format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
	}

	public Integer getNode_id() {
		return node_id;
	}

	public void setNode_id(Integer node_id) {
		this.node_id = node_id;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}

	protected class LiteNode {

		private String name;
		private String type;
		private Map<String, Object> properties;

		public LiteNode(Node node) {
			this.name = node.getName();
			this.type = node.getType().getName();
				
			this.properties = new HashMap<String, Object>();
			for(Property property : node.properties().keySet()) {
				this.properties.put(property.getName(), node.properties().get(property));
			}
			
		}
		
		public String getName() {
			return name;
		}

		public void setName(String name) {
			this.name = name;
		}

		public String getType() {
			return type;
		}

		public void setType(String type) {
			this.type = type;
		}

		public Map<String, Object> getProperties() {
			return properties;
		}

		public void setProperties(Map<String, Object> properties) {
			this.properties = properties;
		}

	}

}
