package fr.graphit.web.api;

import java.util.List;

import com.google.inject.Inject;
import com.google.sitebricks.client.transport.Json;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.reply.ErrorReply;
import fr.graphit.web.api.reply.SuccessReply;
import fr.graphit.web.exception.InvalidParametersException;

public class SearchAPIService implements APIService {

	private String search_term;
	private String format;
	
	private NodesService nodesService;
	
	@Inject
	public SearchAPIService(NodesService nodesService) {
		this.nodesService = nodesService;
		this.format = "http";
	}
	
	@Override
	@Get
	public Reply<?> get() {
		return this.process();
	}
	
	@Override
	@Post
	public Reply<?> post() {
		return this.process();
	}
	
	private Reply<?> process() {
		String error = "";
		try {
			if(search_term==null || search_term.equals("")) {
				throw new InvalidParametersException();
			}
			
			if(format.equals("json")) {
				return Reply.with(new SuccessReply<List<Node>>(nodesService.searchNodesByName(search_term, false))).as(Json.class);
			}
			return Reply.saying().ok();
			
		}
		catch(InvalidParametersException e) {
			error = e.getMessage();
		}
		catch (UnableToRetrieveNodesException e) {
			error = e.getMessage();
		}
		
		if(format.equals("json")) {
			return Reply.with(new ErrorReply(error)).as(Json.class);
		}
		return Reply.saying().error();
	}

	public String getSearch_term() {
		return search_term;
	}

	public void setSearch_term(String search_term) {
		this.search_term = search_term;
	}

	public String getFormat() {
		return format;
	}

	public void setFormat(String format) {
		this.format = format;
	}

}
