package fr.graphit.web.api.graph;

import java.util.List;

import org.apache.log4j.Logger;

import com.google.inject.Injector;
import com.google.inject.Key;
import com.google.inject.name.Names;

import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.graph.provider.GraphProvider;
import fr.graphit.web.exception.GraphException;

public class GraphBuilderMaker extends GraphBuilder {

	private static final Logger logger = Logger.getLogger(GraphBuilder.class);
	
	private String providerName;
	private String engineName;
	
	private List<Node> nodes;
	
	public GraphBuilderMaker(List<Node> nodes) {
		this.nodes = nodes;
	}

	@Override
	public GraphBuilder providedBy(String provider) {
		this.providerName = provider;
		return this;
	}
	
	@Override
	public GraphBuilder renderedBy(String engine) {
		this.engineName = engine;
		return this;
	}

	@Override
	public byte[] asPNG(Injector injector) throws GraphException {
		logger.debug("Rendering as PNG");
		return this.getProvider(injector).png(nodes, engineName);
	}
	
	@Override
	public String asSVG(Injector injector, String urlCallback) throws GraphException {
		logger.debug("Rendering as SVG");
		return this.getProvider(injector).svg(nodes, urlCallback, engineName);
	}
	
	private GraphProvider getProvider(Injector injector) throws GraphException {
		return injector.getInstance(Key.get(GraphProvider.class, Names.named(providerName)));
	}
	

}