package fr.graphit.web.api.graph.graphviz;

import java.util.List;

import org.apache.log4j.Logger;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.model.Node;

public class GraphVizUtils {

	private static final Logger logger = Logger.getLogger(GraphVizUtils.class);
	
	public static String toGV(List<Node> nodes, ModelService model, String urlPrefix) {
		
		String graphStr = "digraph{node[style=filled, fillcolor=white, fontsize=8];";
		
		// add all nodes to graph
		for(Node node : nodes) {
			
			String color = node.getType().getColor();
			String shape = node.getType().getShape();
			
			String strToAdd = "\""
				+ node.getName()
				+ "\" ["
				+ "id=n" + node.getId() + ","
				+ "fillcolor=" + color + ","
				+ "shape="+shape
				+ (urlPrefix != null ? ",URL=\""+urlPrefix + node.getId().toString()+"\"" : "")
				+ "];";
			
			graphStr += strToAdd;
			
		}
		
		// add links to graph
		for (Node node : nodes) {
			
			for (Node parent : node.parents()) {
				
				if(nodes.contains(parent)) {
					String strToAdd = "\""
						+ parent.getName()
						+ "\"->\""
						+ node.getName()
						+ "\";";

					if (!graphStr.contains(strToAdd)) {
						graphStr += strToAdd;
					}
				}
				
			}
			
			for (Node child : node.children()) {
				
				if(nodes.contains(child)) {
					String strToAdd = "\""
						+ node.getName()
						+ "\"->\""
						+ child.getName()
						+ "\";";

					if (!graphStr.contains(strToAdd)) {
						graphStr += strToAdd;
					}
				}
				
			}
			
		}
		
		

		graphStr += "}";
		
		logger.debug("Generated graph : " + graphStr);
		
		return graphStr;
		
	}
	
}
