package fr.graphit.web.api.graph.provider;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.List;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.http.client.ClientProtocolException;
import org.apache.log4j.Logger;

import com.google.inject.Inject;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.graph.graphviz.GraphVizUtils;
import fr.graphit.web.api.graph.provider.google.GoogleChartClient;
import fr.graphit.web.exception.GraphException;

public class GoogleGraphProvider implements GraphProvider {
	
	private static final Logger logger = Logger.getLogger(GoogleGraphProvider.class);
	
	private ModelService modelService;
	
	@Inject
	public GoogleGraphProvider(ModelService modelService) {
		this.modelService = modelService;
	}

	@Override
	public byte[] png(List<Node> nodes, String engine) throws GraphException, UnsupportedOperationException {
		try {
			return GoogleChartClient.init("gv:"+engine, GraphVizUtils.toGV(nodes, modelService, null)).png();
		}
		catch (UnsupportedEncodingException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
		catch (ClientProtocolException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
		catch (IOException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
	}

	@Override
	public String svg(List<Node> nodes, String urlPrefix, String engine) throws GraphException, UnsupportedOperationException {
		throw new UnsupportedOperationException();
	}


}