package fr.graphit.web.api.graph.provider;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.List;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Logger;

import com.google.common.io.Files;
import com.google.inject.Inject;
import com.google.inject.name.Named;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.api.graph.graphviz.GraphVizUtils;
import fr.graphit.web.exception.GraphException;

public class NativeGraphProvider implements GraphProvider {

	private static final Logger logger = Logger.getLogger(NativeGraphProvider.class);
	
	private String path;
	private ModelService modelService;
	private String suffix;
	
	@Inject
	public NativeGraphProvider(@Named("graphit.path") String path, @Named("graphit.suffix") String suffix, ModelService modelService) {
		this.path = path;
		this.modelService = modelService;
		this.suffix = suffix;
	}

	@Override
	public byte[] png(List<Node> nodes, String engine) throws GraphException, UnsupportedOperationException {
		
		try {
			
			String gv = GraphVizUtils.toGV(nodes, modelService, null);
			File gvFile = File.createTempFile("graph_", ".gv");
			File gvImg = File.createTempFile("graph_", ".png");
			Files.write(gv.getBytes(), gvFile);		
			
	        Runtime rt = Runtime.getRuntime();
	        String[] args = {path+engine+suffix, "-Tpng", "-o", gvImg.getAbsolutePath(), gvFile.getAbsolutePath()};
	        Process p = rt.exec(args);
	        p.waitFor();
	        
	        return Files.toByteArray(gvImg);
        
		}
		catch (IOException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
		catch (InterruptedException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}

	}
	
	@Override
	public String svg(List<Node> nodes, String urlPrefix, String engine) throws GraphException, UnsupportedOperationException {
		
		try {
			String gv = GraphVizUtils.toGV(nodes, modelService, urlPrefix);
			File gvFile;
			
			gvFile = File.createTempFile("graph_", ".gv");
			
			File gvImg = File.createTempFile("graph_", ".svg");
			Files.write(gv.getBytes(), gvFile);		
			
	        Runtime rt = Runtime.getRuntime();
	        String[] args = {path+engine+suffix, "-Tsvg", "-o", gvImg.getAbsolutePath(), gvFile.getAbsolutePath()};
	        Process p = rt.exec(args);
	        p.waitFor();
	        
	        return Files.toString(gvImg, Charset.forName("UTF-8"));
		}
		catch (IOException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
		catch (InterruptedException e) {
			if(logger.isDebugEnabled()) {
				logger.debug(ExceptionUtils.getStackTrace(e));
			}
			throw new GraphException();
		}
        
	}


}