package fr.graphit.web.api.graph.provider.google;

import java.io.IOException;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.StatusLine;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpResponseException;
import org.apache.http.client.ResponseHandler;
import org.apache.http.util.EntityUtils;
import org.codehaus.jackson.map.ObjectMapper;

public class JsonResponseHandler<T> implements ResponseHandler<T> {

	private final Class<T> clazz;
	
	public JsonResponseHandler(Class<T> clazz) {
	    this.clazz = clazz;
	}
	
	@Override
	public T handleResponse(HttpResponse response) throws ClientProtocolException, IOException {
		StatusLine statusLine = response.getStatusLine();
        if (statusLine.getStatusCode() >= 300) {
            throw new HttpResponseException(statusLine.getStatusCode(), statusLine.getReasonPhrase());
        }

        HttpEntity entity = response.getEntity();
        
        if(entity == null) {
        	return null;
        }
        
        String content = EntityUtils.toString(entity);
        
        ObjectMapper mapper = new ObjectMapper();
        T reply = mapper.readValue(content, clazz);
        
        return reply;
	}

}
