package fr.graphit.web.client;

import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

public class ViewListService extends AbstractService implements Renderable {
	
	
	@Inject
	public ViewListService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get() {
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		try {
			model.put("views", this.model.getViews());
		}
		catch (UnableToRetrieveViewsException e) {
			errors.add("Unable to list views.");
		}
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.VIEWS;
	}

}
