package fr.graphit.web.client;

import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.inject.name.Named;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

public class ViewService extends AbstractService implements Renderable {
	
	@Inject
	public ViewService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get(@Named("viewId") Integer viewId) {
		if(viewId == null) {
			return Reply.saying().notFound();
		}
		if(session.currentView == null || !session.currentView.equals(viewId)) {
			try {
				session.currentView = model.getView(viewId);
			}
			catch (UnableToRetrieveViewsException e) {
				errors.add(e.getMessage());
			}
			catch (ViewNotFoundException e) {
				errors.add(e.getMessage());
			}

		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		if(session.currentView != null) {
			model.put("view", session.currentView);
		}
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.VIEW;
	}

}
