package fr.graphit.web.client.admin;

import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.UnableToRetrieveTypesException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.core.api.exception.node.UnableToCreateNodeException;
import fr.graphit.core.api.model.Type;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;
import fr.graphit.web.uri.URIContext;

public class AddService extends AbstractService implements Renderable {
	
	private String newName;
	private Integer newType;
	
	@Inject
	public AddService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Post
	public Reply<?> post() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		else if(newName == null || newType == null || newName.equals("")) {
			errors.add("Aucune donnée recue");
		}
		else {
			try {
				Type type = model.getType(newType);
				session.currentNode = nodes.createNode(newName, type);
				return Reply.saying().redirect(URIContext.EDIT);
			}
			catch (NameAlreadyInUseException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToCreateNodeException e) {
				errors.add(e.getMessage());
			}
			catch (TypeNotFoundException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToRetrieveTypesException e) {
				errors.add(e.getMessage());
			}
		}
		session.currentNode = null;
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}
	
	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		
		try {
			model.put("types", this.model.getTypes());
		}
		catch (UnableToRetrieveTypesException e) {
			errors.add("Unable to list types");
		}
		
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.ADDEDIT;
	}

	public String getNewName() {
		return newName;
	}

	public void setNewName(String newName) {
		this.newName = newName;
	}

	public Integer getNewType() {
		return newType;
	}

	public void setNewType(Integer newType) {
		this.newType = newType;
	}
	
}