package fr.graphit.web.client.admin;

import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.UnableToCreateViewException;
import fr.graphit.core.api.exception.node.NameAlreadyInUseException;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;
import fr.graphit.web.uri.URIContext;

public class AddViewService extends AbstractService implements Renderable {
	
	private String newName;
	
	@Inject
	public AddViewService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Post
	public Reply<?> post() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		else if(newName == null || newName.equals("")) {
			errors.add("Aucune donnée recue");
		}
		else {
			try {
				session.currentView = model.createView(newName);
				return Reply.saying().redirect(URIContext.EDIT_VIEW);
			}
			catch (NameAlreadyInUseException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToCreateViewException e) {
				errors.add(e.getMessage());
			}
		}
		session.currentView = null;
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}
	
	@Override
	public Map<String, Object> getModel() {
		return initModel();
	}

	@Override
	public String getTemplate() {
		return TemplateContext.ADDEDITVIEW;
	}

	public String getNewName() {
		return newName;
	}

	public void setNewName(String newName) {
		this.newName = newName;
	}
	
}