package fr.graphit.web.client.admin;

import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.inject.name.Named;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

public class DisplayService extends AbstractService implements Renderable {
	
	@Inject
	public DisplayService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get(@Named("nodeId") Integer nodeId) {
		if(nodeId == null) {
			return Reply.saying().notFound();
		}
		if(session.currentNode == null || !session.currentNode.getId().equals(nodeId)) {
			try {
				session.currentNode = nodes.getNodeById(nodeId);
			}
			catch (NodeNotFoundException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToRetrieveNodesException e) {
				errors.add(e.getMessage());
			}
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		if(session.currentNode != null) {
			model.put("node", session.currentNode);
		}
		model.put("properties", session.currentNode.getType().properties());
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.DISPLAY;
	}

}
