package fr.graphit.web.client.admin;

import java.util.HashMap;
import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.TypeNotFoundException;
import fr.graphit.core.api.exception.model.UnableToRetrieveTypesException;
import fr.graphit.core.api.exception.node.NodeNotFoundException;
import fr.graphit.core.api.exception.node.UnableToUpdateNodeException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.Property;
import fr.graphit.core.api.model.Type;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

/**
 * A sitebricks service to edit an item
 * @author Thomas Clarisse
 *
 */
public class EditService extends AbstractService implements Renderable {
	
	private String newName;
	private Integer newType;
	private Map<Integer, Object> newProperties;
	
	@Inject
	public EditService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Get
	public Reply<?> get() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		if(session.currentNode == null) {
			errors.add("Aucun élément ouvert");
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Post
	public Reply<?> post() {
		if(!session.isAdmin) {
			return Reply.saying().error();
		}
		else if(session.currentNode == null || newName == null || newType == null || newProperties == null || newName.equals("")) {
			errors.add("Aucune donnée recue");
		}
		else {
			try {
				
				Node node = injector.getInstance(Node.class);
				node.setId(session.currentNode.getId());
				node.setName(newName);
				
				Type type = model.getType(newType);
				node.setType(type);
				
				Map<Property, Object> newPropertiesInNode = new HashMap<Property, Object>();
				for(Integer propertyId : newProperties.keySet()) {
					newPropertiesInNode.put(type.getProperty(propertyId), newProperties.get(propertyId));
				}
				
				node.setProperties(newPropertiesInNode);
			
				session.currentNode = nodes.updateNode(node);
			}
			catch (NodeNotFoundException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToUpdateNodeException e) {
				errors.add(e.getMessage());
			}
			catch (UnableToRetrieveTypesException e) {
				errors.add(e.getMessage());
			} 
			catch (TypeNotFoundException e) {
				errors.add(e.getMessage());
			}
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}
	
	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		if(session.currentNode != null) {
			model.put("node", session.currentNode);
		}
		try {
			model.put("types", this.model.getTypes());
		}
		catch (UnableToRetrieveTypesException e) {
			errors.add(e.getMessage());
		}
		
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.ADDEDIT;
	}

	public String getNewName() {
		return session.currentNode.getName();
	}

	public void setNewName(String newName) {
		this.newName = newName;
	}

	public Integer getNewType() {
		return session.currentNode.getType().getId();
	}

	public void setNewType(Integer newType) {
		this.newType = newType;
	}

	public Map<Integer, Object> getNewProperties() {
		return new HashMap<Integer, Object>();
	}

	public void setNewProperties(Map<Integer, Object> newProperties) {
		this.newProperties = newProperties;
	}

	
	
}
