package fr.graphit.web.client.admin;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.model.UnableToRetrieveViewsException;
import fr.graphit.core.api.exception.model.UnableToUpdateViewException;
import fr.graphit.core.api.exception.model.ViewNotFoundException;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.core.api.model.View;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

public class EditViewService extends AbstractService implements Renderable {

	private String newName;
	private Integer view_id;

	@Inject
	public EditViewService(Injector injector, UIMessages messages,
			TemplateEngine templateEngine, NodesService nodes,
			ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}

	@Get
	public Reply<?> get() {
		if (!session.isAdmin) {
			return Reply.saying().error();
		}
		if (view_id != null) {
			try {
				session.currentView = model.getView(view_id);
			}
			catch (UnableToRetrieveViewsException e) {
				errors.add(e.getMessage());
			}
			catch (ViewNotFoundException e) {
				errors.add(e.getMessage());
			}
		}
		if (session.currentView == null) {
			errors.add("Aucun élément ouvert");
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}

	@Post
	public Reply<?> post() {
		if (!session.isAdmin) {
			return Reply.saying().error();
		}
		else if (session.currentView == null || newName == null
				|| newName.equals("")) {
			errors.add("Aucune donnée recue");
		}
		else {
			try {

				View view = injector.getInstance(View.class);
				view.setId(session.currentView.getId());
				view.setName(newName);

				session.currentView = model.updateView(view);
			}
			catch (UnableToUpdateViewException e) {
				errors.add(e.getMessage());
			}
			catch (ViewNotFoundException e) {
				errors.add(e.getMessage());
			}
		}
		return Reply.with(templateEngine.renderAsHtml(this)).type(
				"text/html; charset=utf-8");
	}

	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		try {
			if (session.currentView != null) {
				List<Node> nodes = this.nodes.searchNodesByView(session.currentView);
				model.put("view", session.currentView);
				model.put("nodes", nodes);
				model.put("suggestions", this.getSuggestions(nodes));
			}
		} catch (UnableToRetrieveNodesException e) {
			errors.add(e.getMessage());
		} catch (ViewNotFoundException e) {
			errors.add(e.getMessage());
		}
		return model;
	}

	private List<Node> getSuggestions(List<Node> nodes) {
		List<Node> suggestions = new ArrayList<Node>();
		
		for(Node node : nodes) {
			for(Node parent : node.parents()) {
				if(!nodes.contains(parent) && !suggestions.contains(parent)) {
					suggestions.add(parent);
				}
			}
			for(Node child : node.children()) {
				if(!nodes.contains(child) && !suggestions.contains(child)) {
					suggestions.add(child);
				}
			}
		}
		
		return suggestions;
	}
	
	@Override
	public String getTemplate() {
		return TemplateContext.ADDEDITVIEW;
	}

	public String getNewName() {
		return session.currentView.getName();
	}

	public void setNewName(String newName) {
		this.newName = newName;
	}

	public Integer getView_id() {
		return view_id;
	}

	public void setView_id(Integer view_id) {
		this.view_id = view_id;
	}


}
