package fr.graphit.web.client.admin;

import java.util.List;
import java.util.Map;

import com.google.inject.Inject;
import com.google.inject.Injector;
import com.google.sitebricks.headless.Reply;
import com.google.sitebricks.http.Get;
import com.google.sitebricks.http.Post;

import fr.graphit.core.api.ModelService;
import fr.graphit.core.api.NodesService;
import fr.graphit.core.api.exception.node.UnableToRetrieveNodesException;
import fr.graphit.core.api.model.Node;
import fr.graphit.web.client.AbstractService;
import fr.graphit.web.client.template.Renderable;
import fr.graphit.web.client.template.TemplateContext;
import fr.graphit.web.client.template.TemplateEngine;
import fr.graphit.web.messages.UIMessages;
import fr.graphit.web.session.SessionHandler;

public class SearchService extends AbstractService implements Renderable {

	private String searchInput;
	private List<Node> candidates;
	
	@Inject
	public SearchService(Injector injector, UIMessages messages, TemplateEngine templateEngine, NodesService nodes, ModelService model, SessionHandler session) {
		super(injector, messages, templateEngine, nodes, model, session);
	}
	
	@Post
	public Reply<?> search() {
		if(searchInput != null && !searchInput.equals("")) {
			try {
				this.candidates = nodes.searchNodesByName(searchInput, false);
			}
			catch (UnableToRetrieveNodesException e) {
				errors.add(e.getMessage());
			}
		}
		return render();
	}
	
	@Get
	public Reply<String> get() {
		return render();
	}

	private Reply<String> render() {
		return Reply.with(templateEngine.renderAsHtml(this)).type("text/html; charset=utf-8");
	}
	
	@Override
	public Map<String, Object> getModel() {
		Map<String, Object> model = initModel();
		if(this.candidates != null && this.candidates.size() > 0) {
			model.put("nodes", this.candidates);
		}
		return model;
	}

	@Override
	public String getTemplate() {
		return TemplateContext.SEARCH;
	}

	public String getSearchInput() {
		return searchInput;
	}

	public void setSearchInput(String searchInput) {
		this.searchInput = searchInput;
	}
		
}
