package fr.graphit.web.client.template;

import java.io.IOException;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;

import fr.graphit.web.WebModule;
import freemarker.ext.beans.BeansWrapper;
import freemarker.template.Configuration;
import freemarker.template.Template;
import freemarker.template.TemplateException;

public class TemplateEngine {

	private Configuration configuration;
	
	public TemplateEngine() {
		this.configuration = new Configuration();
		this.configuration.setClassForTemplateLoading(WebModule.class, "/");
		this.configuration.setTemplateUpdateDelay(0);
		BeansWrapper wrapper = new BeansWrapper(); 
        wrapper.setSimpleMapWrapper(true); 
		this.configuration.setObjectWrapper(wrapper); 
	}
	
	public String renderAsHtml(Renderable renderable) {
		return this.render(renderable.getTemplate(), renderable.getModel());
	}
	
	private String render(String templatePath, Map<String, Object> model) {
		try {
			Template template = configuration.getTemplate(templatePath);
			Writer out = new StringWriter();
			template.setEncoding("utf-8");
			template.process(model, out);
	        out.flush();
	        return out.toString();
		}
		catch (IOException e) {
			e.printStackTrace();
		}
		catch (TemplateException e) {
			e.printStackTrace();
		}
		return "Templating Error";
	}
	
}